@@ -550,9 +550,9 @@ def MainScreen():
 
     def advance_time(self, proportion):
       if self.step == -1:
-        info_banner.advance_time(proportion)
+        info_banner.widget_advance_time(proportion)
       else:
-        pub_banner.advance_time(proportion)
+        pub_banner.widget_advance_time(proportion)
 
       if self.step == 0:
         if self.ltime < 150.0:
